The team
========

These are the people that created, that work or worked in thumbor across
the releases:

Founders / Committers
---------------------

-  `@heynemann <https://github.com/heynemann/>`_ - Founder and active
   committer
-  `@cezarsa <https://github.com/cezarsa/>`_ - Committer
-  `@fabiomcosta <https://github.com/fabiomcosta/>`_ - Founder and committer

Contributors
------------

Contributors can be found in the `Contributors
page <https://github.com/thumbor/thumbor/graphs/contributors>`__.
